@@ -1,19 +1,16 @@
-
-/*  $Header$
- *
- *  Copyright (c) 1987-2008 Sun Microsystems, Inc. All Rights Reserved.
+/*  Copyright (c) 1987-2008 Sun Microsystems, Inc. All Rights Reserved.
  *  Copyright (c) 2008-2009 Robert Ancell
- *           
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2, or (at your option)
  *  any later version.
- *           
- *  This program is distributed in the hope that it will be useful, but 
+ *
+ *  This program is distributed in the hope that it will be useful, but
  *  WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  *  General Public License for more details.
- *           
+ *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
@@ -28,15 +25,10 @@
 #include "mp.h"
 #include "mp-internal.h"
 
-/*  COMPARES MP NUMBER X WITH INTEGER I, RETURNING
- *      +1 IF X  >  I,
- *       0 IF X == I,
- *      -1 IF X  <  I
- */
 static int
 mp_compare_mp_to_int(const MPNumber *x, int i)
 {
-    MPNumber t;   
+    MPNumber t;
     mp_set_from_integer(i, &t);
     return mp_compare_mp_to_mp(x, &t);
 }
@@ -60,7 +52,7 @@ convert_to_radians(const MPNumber *x, MPAngleUnit unit, MPNumber *z)
         mp_divide_integer(&t2, 180, z);
         break;
 
-    case MP_GRADIANS:        
+    case MP_GRADIANS:
         mp_get_pi(&t1);
         mp_multiply(x, &t1, &t2);
         mp_divide_integer(&t2, 200, z);
@@ -72,7 +64,7 @@ convert_to_radians(const MPNumber *x, MPAngleUnit unit, MPNumber *z)
 void
 mp_get_pi(MPNumber *z)
 {
-    mp_set_from_string("3.1415926535897932384626433832795028841971693993751058209749445923078164062862089986280348253421170679", 10, z);
+    mp_set_from_string("3.1415926535897932384626433832795028841971693993751058209749445923078164062862089986280348253421170679", z);
 }
 
 
@@ -80,19 +72,19 @@ static void
 convert_from_radians(const MPNumber *x, MPAngleUnit unit, MPNumber *z)
 {
     MPNumber t1, t2;
-    
+
     switch (unit) {
     default:
     case MP_RADIANS:
         mp_set_from_mp(x, z);
         break;
-        
+
     case MP_DEGREES:
         mp_multiply_integer(x, 180, &t2);
         mp_get_pi(&t1);
         mp_divide(&t2, &t1, z);
         break;
-        
+
     case MP_GRADIANS:
         mp_multiply_integer(x, 200, &t2);
         mp_get_pi(&t1);
@@ -102,8 +94,8 @@ convert_from_radians(const MPNumber *x, MPAngleUnit unit, MPNumber *z)
 }
 
 
-/*  COMPUTES Z = SIN(X) IF DO_SIN != 0, Z = COS(X) IF DO_SIN == 0,
- *  USING TAYLOR SERIES.   ASSUMES ABS(X) <= 1.
+/* z = sin(x) -1 >= x >= 1, do_sin = 1
+ * z = cos(x) -1 >= x >= 1, do_sin = 0
  */
 static void
 mpsin1(const MPNumber *x, MPNumber *z, int do_sin)
@@ -135,6 +127,7 @@ mpsin1(const MPNumber *x, MPNumber *z, int do_sin)
         i = 2;
     }
 
+    /* Taylor series */
     /* POWER SERIES LOOP.  REDUCE T IF POSSIBLE */
     b2 = max(MP_BASE, 64) << 1;
     do {
@@ -152,7 +145,7 @@ mpsin1(const MPNumber *x, MPNumber *z, int do_sin)
             mp_divide_integer(&t1, -i * (i + 1), &t1);
         }
         mp_add(&t1, z, z);
-        
+
         i += 2;
     } while (t1.sign != 0);
 
@@ -161,12 +154,6 @@ mpsin1(const MPNumber *x, MPNumber *z, int do_sin)
 }
 
 
-/*  RETURNS Z = SIN(X) FOR MP X AND Z,
- *  METHOD IS TO REDUCE X TO (-1, 1) AND USE MPSIN1, SO
- *  TIME IS O(M(T)T/LOG(T)).
- *  DIMENSION OF R IN CALLING PROGRAM MUST BE AT LEAST 5T+12
- *  CHECK LEGALITY OF B, T, M AND MXR
- */
 void
 mp_sin(const MPNumber *x, MPAngleUnit unit, MPNumber *z)
 {
@@ -220,7 +207,7 @@ mp_sin(const MPNumber *x, MPAngleUnit unit, MPNumber *z)
         if (x_radians.sign == 0) {
             mp_set_from_integer(0, z);
             return;
-        }        
+        }
 
         x_radians.sign = 1;
         mp_multiply_integer(&x_radians, 2, &x_radians);
@@ -252,13 +239,10 @@ mp_sin(const MPNumber *x, MPAngleUnit unit, MPNumber *z)
 }
 
 
-/*  RETURNS Z = COS(X) FOR MP X AND Z, USING MP_SIN AND MPSIN1.
- *  DIMENSION OF R IN COMMON AT LEAST 5T+12.
- */
 void
 mp_cos(const MPNumber *xi, MPAngleUnit unit, MPNumber *z)
 {
-    /* cos(0) = 1 */    
+    /* cos(0) = 1 */
     if (xi->sign == 0) {
         mp_set_from_integer(1, z);
         return;
@@ -282,7 +266,7 @@ mp_cos(const MPNumber *xi, MPAngleUnit unit, MPNumber *z)
 }
 
 
-void 
+void
 mp_tan(const MPNumber *x, MPAngleUnit unit, MPNumber *z)
 {
     MPNumber cos_x, sin_x;
@@ -291,23 +275,16 @@ mp_tan(const MPNumber *x, MPAngleUnit unit, MPNumber *z)
     mp_cos(x, unit, &cos_x);
     if (mp_is_zero(&cos_x)) {
         /* Translators: Error displayed when tangent value is undefined */
-        mperr(_("Tangent is infinite"));
+        mperr(_("Tangent not defined for angles that are multiples of π∕2 (180°) from π∕4 (90°)"));
         return;
     }
-    
+
     /* tan(x) = sin(x) / cos(x) */
     mp_sin(x, unit, &sin_x);
     mp_divide(&sin_x, &cos_x, z);
 }
 
 
-/*  RETURNS Z = ARCSIN(X), ASSUMING ABS(X) <= 1,
- *  FOR MP NUMBERS X AND Z.
- *  Z IS IN THE RANGE -PI/2 TO +PI/2.
- *  METHOD IS TO USE MP_ATAN, SO TIME IS O(M(T)T).
- *  DIMENSION OF R MUST BE AT LEAST 5T+12
- *  CHECK LEGALITY OF B, T, M AND MXR
- */
 void
 mp_asin(const MPNumber *x, MPAngleUnit unit, MPNumber *z)
 {
@@ -334,31 +311,19 @@ mp_asin(const MPNumber *x, MPAngleUnit unit, MPNumber *z)
 
     /* HERE ABS(X) >= 1.  SEE IF X == +-1 */
     mp_set_from_integer(x->sign, &t2);
-    if (!mp_is_equal(x, &t2))
-        mperr("*** ABS(X) > 1 IN CALL TO MP_ASIN ***");
+    if (!mp_is_equal(x, &t2)) {
+        /* Translators: Error displayed when inverse sine value is undefined */
+        mperr(_("Inverse sine not defined for values outside [-1, 1]"));
+    }
 
     /* X == +-1 SO RETURN +-PI/2 */
     mp_get_pi(z);
     mp_divide_integer(z, t2.sign << 1, z);
-    
+
     convert_from_radians(z, unit, z);
 }
 
 
-/*  MP precision arc cosine.
- *
- *  1. If (x < -1  or x > 1) then report DOMAIN error and return 0.
- *
- *  2. If (x == 0) then acos(x) = PI/2.
- *
- *  3. If (x == 1) then acos(x) = 0
- *
- *  4. If (x == -1) then acos(x) = PI.
- *
- *  5. If (0 < x < 1) then  acos(x) = atan(sqrt(1-x^2) / x)
- *
- *  6. If (-1 < x < 0) then acos(x) = atan(sqrt(1-x^2) / x) + PI
- */
 void
 mp_acos(const MPNumber *x, MPAngleUnit unit, MPNumber *z)
 {
@@ -370,7 +335,8 @@ mp_acos(const MPNumber *x, MPAngleUnit unit, MPNumber *z)
     mp_set_from_integer(-1, &MPn1);
 
     if (mp_is_greater_than(x, &t1) || mp_is_less_than(x, &MPn1)) {
-        mperr("Error");
+        /* Translators: Error displayed when inverse cosine value is undefined */
+        mperr(_("Inverse cosine not defined for values outside [-1, 1]"));
         mp_set_from_integer(0, z);
     } else if (x->sign == 0) {
         mp_divide_integer(&pi, 2, z);
@@ -378,7 +344,7 @@ mp_acos(const MPNumber *x, MPAngleUnit unit, MPNumber *z)
         mp_set_from_integer(0, z);
     } else if (mp_is_equal(x, &MPn1)) {
         mp_set_from_mp(&pi, z);
-    } else { 
+    } else {
         mp_multiply(x, x, &t2);
         mp_subtract(&t1, &t2, &t2);
         mp_sqrt(&t2, &t2);
@@ -390,21 +356,11 @@ mp_acos(const MPNumber *x, MPAngleUnit unit, MPNumber *z)
             mp_add(&MPy, &pi, z);
         }
     }
-    
+
     convert_from_radians(z, unit, z);
 }
 
 
-/*  RETURNS Z = ARCTAN(X) FOR MP X AND Z, USING AN O(T.M(T)) METHOD
- *  WHICH COULD EASILY BE MODIFIED TO AN O(SQRT(T)M(T))
- *  METHOD (AS IN MPEXP). Z IS IN THE RANGE -PI/2 TO +PI/2.
- *  FOR AN ASYMPTOTICALLY FASTER METHOD, SEE - FAST MULTIPLE-
- *  PRECISION EVALUATION OF ELEMENTARY FUNCTIONS
- *  (BY R. P. BRENT), J. ACM 23 (1976), 242-251,
- *  AND THE COMMENTS IN MPPIGL.
- *  DIMENSION OF R IN CALLING PROGRAM MUST BE AT LEAST 5T+12
- *  CHECK LEGALITY OF B, T, M AND MXR
- */
 void
 mp_atan(const MPNumber *x, MPAngleUnit unit, MPNumber *z)
 {
@@ -444,7 +400,7 @@ mp_atan(const MPNumber *x, MPAngleUnit unit, MPNumber *z)
     for (i = 1; ; i += 2) {
         if (MP_T + 2 + t2.exponent <= 1)
             break;
-        
+
         mp_multiply(&t2, &t1, &t2);
         mp_multiply_fraction(&t2, -i, i + 2, &t2);
 
@@ -487,7 +443,7 @@ mp_sinh(const MPNumber *x, MPNumber *z)
     /* If |x| < 1 USE MPEXP TO AVOID CANCELLATION, otherwise IF TOO LARGE MP_EPOWY GIVES ERROR MESSAGE */
     if (abs_x.exponent <= 0) {
         MPNumber exp_x, a, b;
-        
+
         /* ((e^|x| + 1) * (e^|x| - 1)) / e^|x| */
         // FIXME: Solves to e^|x| - e^-|x|, why not lower branch always? */
         mp_epowy(&abs_x, &exp_x);
@@ -516,7 +472,7 @@ mp_cosh(const MPNumber *x, MPNumber *z)
 {
     MPNumber t;
 
-    /* cosh(0) = 1 */    
+    /* cosh(0) = 1 */
     if (x->sign == 0) {
         mp_set_from_integer(1, z);
         return;
@@ -537,7 +493,7 @@ mp_tanh(const MPNumber *x, MPNumber *z)
     float r__1;
     MPNumber t;
 
-    /* tanh(0) = 0 */    
+    /* tanh(0) = 0 */
     if (x->sign == 0) {
         mp_set_from_integer(0, z);
         return;
@@ -594,11 +550,12 @@ mp_acosh(const MPNumber *x, MPNumber *z)
     /* Check x >= 1 */
     mp_set_from_integer(1, &t);
     if (mp_is_less_than(x, &t)) {
-        mperr("Error");
+        /* Translators: Error displayed when inverse hyperbolic cosine value is undefined */
+        mperr(_("Inverse hyperbolic cosine not defined for values less than or equal to one"));
         mp_set_from_integer(0, z);
         return;
     }
-    
+
     /* acosh(x) = ln(x + sqrt(x^2 - 1)) */
     mp_multiply(x, x, &t);
     mp_add_integer(&t, -1, &t);
@@ -617,11 +574,12 @@ mp_atanh(const MPNumber *x, MPNumber *z)
     mp_set_from_integer(1, &one);
     mp_set_from_integer(-1, &minus_one);
     if (mp_is_greater_equal(x, &one) || mp_is_less_equal(x, &minus_one)) {
-        mperr("Error");
+        /* Translators: Error displayed when inverse hyperbolic tangent value is undefined */
+        mperr(_("Inverse hyperbolic tangent not defined for values outside [-1, 1]"));
         mp_set_from_integer(0, z);
         return;
     }
-    
+
     /* atanh(x) = 0.5 * ln((1 + x) / (1 - x)) */
     mp_add_integer(x, 1, &n);
     mp_set_from_mp(x, &d);
