@@ -1,19 +1,17 @@
 
-/*  $Header$
- *
- *  Copyright (c) 1987-2008 Sun Microsystems, Inc. All Rights Reserved.
+/*  Copyright (c) 1987-2008 Sun Microsystems, Inc. All Rights Reserved.
  *  Copyright (c) 2008-2009 Robert Ancell
- *           
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2, or (at your option)
  *  any later version.
- *           
- *  This program is distributed in the hope that it will be useful, but 
+ *
+ *  This program is distributed in the hope that it will be useful, but
  *  WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  *  General Public License for more details.
- *           
+ *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
@@ -41,6 +39,8 @@
 #ifndef MP_H
 #define MP_H
 
+#include <glib.h>
+
 /* Size of the multiple precision values */
 #define MP_SIZE 1000
 
@@ -48,7 +48,7 @@
 #define MP_BASE 10000
 
 /* Object for a high precision floating point number representation
- * 
+ *
  * x = sign * (MP_BASE^(exponent-1) + MP_BASE^(exponent-2) + ...)
  */
 typedef struct
@@ -175,7 +175,7 @@ void   mp_sqrt(const MPNumber *x, MPNumber *z);
 void   mp_factorial(const MPNumber *x, MPNumber *z);
 
 /* Sets z = x mod y */
-void  mp_modulus_divide(const MPNumber *x, const MPNumber *y, MPNumber *z);
+void   mp_modulus_divide(const MPNumber *x, const MPNumber *y, MPNumber *z);
 
 /* Sets z = x^y */
 void   mp_xpowy(const MPNumber *x, const MPNumber *y, MPNumber *z);
@@ -186,6 +186,9 @@ void   mp_xpowy_integer(const MPNumber *x, int y, MPNumber *z);
 /* Sets z = e^x */
 void   mp_epowy(const MPNumber *x, MPNumber *z);
 
+/* Returns a list of all prime factors in x as MPNumbers */
+GList* mp_factorize(const MPNumber *x);
+
 /* Sets z = x */
 void   mp_set_from_mp(const MPNumber *x, MPNumber *z);
 
@@ -204,10 +207,10 @@ void   mp_set_from_fraction(int numerator, int denominator, MPNumber *z);
 /* Sets z to be a uniform random number in the range [0, 1] */
 void   mp_set_from_random(MPNumber *z);
 
-/* Sets z from a string representation in 'text' in base 'base'.
+/* Sets z from a string representation in 'text'.
  * Returns 0 on success.
  */
-int    mp_set_from_string(const char *text, int base, MPNumber *z);
+int    mp_set_from_string(const char *text, MPNumber *z);
 
 /* Returns x as a native single-precision floating point number */
 float  mp_cast_to_float(const MPNumber *x);
